@@ -36,6 +36,7 @@
 #include <libgnome-desktop/gnome-rr.h>
 
 #include "gnome-settings-profile.h"
+#include "gnome-settings-session.h"
 #include "gsd-color-manager.h"
 #include "gcm-profile-store.h"
 #include "gcm-dmi.h"
@@ -49,6 +50,7 @@
 
 struct GsdColorManagerPrivate
 {
+        GnomeSettingsSession *session;
         CdClient        *client;
         GSettings       *settings;
         GcmProfileStore *profile_store;
@@ -828,12 +830,19 @@ gcm_session_device_set_gamma (GnomeRROutput *output,
                               CdProfile *profile,
                               GError **error)
 {
-        gboolean ret;
+        gboolean ret = FALSE;
         GPtrArray *clut = NULL;
 
         /* create a lookup table */
         clut = gcm_session_generate_vcgt (profile,
                                           gnome_rr_output_get_gamma_size (output));
+        if (clut == NULL) {
+                g_set_error_literal (error,
+                                     GSD_COLOR_MANAGER_ERROR,
+                                     GSD_COLOR_MANAGER_ERROR_FAILED,
+                                     "failed to generate vcgt");
+                goto out;
+        }
 
         /* apply the vcgt to this output */
         ret = gcm_session_output_set_gamma (output, clut, error);
@@ -1154,8 +1163,11 @@ gcm_session_create_device_cb (GObject *object,
                                                  res,
                                                  &error);
         if (device == NULL) {
-                g_warning ("failed to create device: %s",
-                           error->message);
+                if (error->domain != CD_CLIENT_ERROR ||
+                    error->code != CD_CLIENT_ERROR_ALREADY_EXISTS) {
+                        g_warning ("failed to create device: %s",
+                                   error->message);
+                }
                 g_error_free (error);
                 return;
         }
@@ -1784,7 +1796,9 @@ gcm_session_create_profile_cb (GObject *object,
 
         profile = cd_client_create_profile_finish (client, res, &error);
         if (profile == NULL) {
-                g_warning ("%s", error->message);
+                if (error->domain != CD_CLIENT_ERROR ||
+                    error->code != CD_CLIENT_ERROR_ALREADY_EXISTS)
+                        g_warning ("%s", error->message);
                 g_error_free (error);
                 return;
         }
@@ -1813,7 +1827,9 @@ gcm_session_profile_store_added_cb (GcmProfileStore *profile_store,
                 g_error_free (error);
                 goto out;
         }
-        profile_id = g_strdup_printf ("icc-%s", checksum);
+        profile_id = g_strdup_printf ("icc-%s-%s",
+                                      checksum,
+                                      g_get_user_name ());
         profile_props = g_hash_table_new_full (g_str_hash, g_str_equal,
                                                NULL, NULL);
         g_hash_table_insert (profile_props,
@@ -1929,6 +1945,28 @@ gcm_session_sensor_removed_cb (CdClient *client,
 #endif
 }
 
+static void
+gcm_session_active_changed_cb (GnomeSettingsSession *session,
+                               GParamSpec *pspec,
+                               GsdColorManager *manager)
+{
+        GnomeSettingsSessionState state;
+
+        /* not yet connected to the daemon */
+        if (!cd_client_get_connected (manager->priv->client))
+                return;
+
+        /* when doing the fast-user-switch into a new account, load the
+         * new users chosen profiles */
+        state = gnome_settings_session_get_state (session);
+        if (state == GNOME_SETTINGS_SESSION_STATE_ACTIVE) {
+                g_debug ("Done switch to new account, reload devices");
+                cd_client_get_devices (manager->priv->client, NULL,
+                                       gcm_session_get_devices_cb,
+                                       manager);
+        }
+}
+
 static void
 gsd_color_manager_set_property (GObject        *object,
                                 guint           prop_id,
@@ -1980,6 +2018,12 @@ gsd_color_manager_init (GsdColorManager *manager)
         GsdColorManagerPrivate *priv;
         priv = manager->priv = GSD_COLOR_MANAGER_GET_PRIVATE (manager);
 
+        /* track the active session */
+        priv->session = gnome_settings_session_new ();
+        g_signal_connect (priv->session, "notify::state",
+                          G_CALLBACK (gcm_session_active_changed_cb),
+                          manager);
+
         /* set the _ICC_PROFILE atoms on the root screen */
         priv->gdk_window = gdk_screen_get_root_window (gdk_screen_get_default ());
 
@@ -2030,6 +2074,7 @@ gsd_color_manager_finalize (GObject *object)
         g_object_unref (manager->priv->client);
         g_object_unref (manager->priv->profile_store);
         g_object_unref (manager->priv->dmi);
+        g_object_unref (manager->priv->session);
         g_hash_table_destroy (manager->priv->edid_cache);
         if (manager->priv->x11_screen != NULL)
                 g_object_unref (manager->priv->x11_screen);
