@@ -2,27 +2,29 @@
  *
  * gsd-ldsm-dialog.c
  * Copyright (C) Chris Coulson 2009 <chrisccoulson@googlemail.com>
- * 
- * gsd-ldsm-dialog.c is free software: you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation, either version 3 of the License, or
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
- * gsd-ldsm-dialog.c is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License along
- * with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
 #include <glib/gi18n.h>
-#include <gconf/gconf-client.h>
+#include <gio/gio.h>
 
 #include "gsd-ldsm-dialog.h"
 
-#define GCONF_CLIENT_IGNORE_PATHS "/apps/gnome_settings_daemon/plugins/housekeeping/ignore_paths"
+#define SETTINGS_HOUSEKEEPING_DIR     "org.gnome.settings-daemon.plugins.housekeeping"
 
 enum
 {
@@ -73,7 +75,7 @@ gsd_ldsm_dialog_get_primary_text (GsdLdsmDialog *dialog)
 	
         g_return_val_if_fail (GSD_IS_LDSM_DIALOG (dialog), NULL);
 	
-        free_space = g_format_size_for_display (dialog->priv->space_remaining);
+        free_space = g_format_size (dialog->priv->space_remaining);
 	
         if (dialog->priv->other_partitions) {
                 primary_text = g_strdup_printf (_("The volume \"%s\" has only %s disk space remaining."),
@@ -149,45 +151,44 @@ ignore_check_button_toggled_cb (GtkToggleButton *button,
                                 gpointer user_data)
 {
         GsdLdsmDialog *dialog = (GsdLdsmDialog *)user_data;
-        GConfClient *client;
-        GSList *ignore_paths;
-        GError *error = NULL;
-        gboolean ignore, ret, updated;
-        
-        client = gconf_client_get_default ();
-        if (client != NULL) {
-                ignore_paths = gconf_client_get_list (client,
-                                                      GCONF_CLIENT_IGNORE_PATHS,
-                                                      GCONF_VALUE_STRING, &error);
-                if (error != NULL) {
-                        g_warning ("Cannot change ignore preference - failed to read existing configuration: %s",
-                                   error->message ? error->message : "Unkown error");
-                        g_clear_error (&error);
-                        return;
-                } else {
-                        ignore = gtk_toggle_button_get_active (button);
-                        updated = update_ignore_paths (&ignore_paths, dialog->priv->mount_path, ignore); 
+        GSettings *settings;
+        gchar **settings_list;
+        gboolean ignore, updated;
+        gint i;
+        GSList *ignore_paths = NULL;
+
+        settings = g_settings_new (SETTINGS_HOUSEKEEPING_DIR);
+
+        settings_list = g_settings_get_strv (settings, "ignore-paths");
+
+        for (i = 0; i < G_N_ELEMENTS (settings_list); i++) {
+                if (settings_list[i] != NULL)
+                        ignore_paths = g_slist_append (ignore_paths, g_strdup (settings_list[i]));
+        }
+
+        ignore = gtk_toggle_button_get_active (button);
+        updated = update_ignore_paths (&ignore_paths, dialog->priv->mount_path, ignore);
+
+        g_strfreev (settings_list);
+
+        if (updated) {
+                GSList *l;
+                GPtrArray *array = g_ptr_array_new ();
+
+                for (l = ignore_paths; l != NULL; l = l->next)
+                        g_ptr_array_add (array, l->data);
+                g_ptr_array_add (array, NULL);
+
+                if (!g_settings_set_strv (settings, "ignore-paths", (const gchar **) array->pdata)) {
+                        g_warning ("Cannot change ignore preference - failed to commit changes");
                 }
-                
-                if (!updated)
-                        return;
-                
-                ret = gconf_client_set_list (client,
-                                             GCONF_CLIENT_IGNORE_PATHS,
-                                             GCONF_VALUE_STRING,
-                                             ignore_paths, &error);
-                if (!ret || error != NULL) {
-                        g_warning ("Cannot change ignore preference - failed to commit changes: %s",
-                                   error->message ? error->message : "Unkown error");
-                        g_clear_error (&error);
-                }
-                
-                g_slist_foreach (ignore_paths, (GFunc) g_free, NULL);
-                g_slist_free (ignore_paths);
-                g_object_unref (client);
-        } else {
-                g_warning ("Cannot change ignore preference - failed to get GConfClient");
-        }     
+
+                g_ptr_array_free (array, FALSE);
+        }
+
+        g_slist_foreach (ignore_paths, (GFunc) g_free, NULL);
+        g_slist_free (ignore_paths);
+        g_object_unref (settings);
 }
 
 static void
@@ -210,9 +211,6 @@ gsd_ldsm_dialog_init (GsdLdsmDialog *dialog)
         gtk_window_set_focus_on_map (GTK_WINDOW (dialog), FALSE);
         gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 
-        /* We don't want a separator - they're really ugly */
-        gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-
         /* Create the image */
         image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_DIALOG);
         gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
@@ -231,7 +229,7 @@ gsd_ldsm_dialog_init (GsdLdsmDialog *dialog)
         /* Create the check button to ignore future warnings */
         dialog->priv->ignore_check_button = gtk_check_button_new ();
         /* The button should be inactive if the dialog was just called.
-         * I suppose it could be possible for the user to manually edit the GConf key between
+         * I suppose it could be possible for the user to manually edit the GSettings key between
          * the mount being checked and the dialog appearing, but I don't think it matters
          * too much */
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->ignore_check_button), FALSE);
