@@ -34,6 +34,9 @@
 
 #define GSD_MEDIA_KEYS_WINDOW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GSD_TYPE_MEDIA_KEYS_WINDOW, GsdMediaKeysWindowPrivate))
 
+/* The size of the icon compared to the whole OSD */
+#define ICON_SCALE 0.50
+
 struct GsdMediaKeysWindowPrivate
 {
         GsdMediaKeysWindowAction action;
@@ -371,8 +374,6 @@ draw_volume_boxes (GsdMediaKeysWindow *window,
         GtkStyleContext *context;
         GdkRGBA  acolor;
 
-        _x0 += 0.5;
-        _y0 += 0.5;
         height = round (height) - 1;
         width = round (width) - 1;
         x1 = round ((width - 1) * percentage);
@@ -385,23 +386,14 @@ draw_volume_boxes (GsdMediaKeysWindow *window,
         acolor.alpha = GSD_OSD_WINDOW_FG_ALPHA / 2;
         gsd_osd_window_draw_rounded_rectangle (cr, 1.0, _x0, _y0, height / 6, width, height);
         gdk_cairo_set_source_rgba (cr, &acolor);
-        cairo_fill_preserve (cr);
-
-        /* bar border */
-        gtk_style_context_get_background_color (context, GTK_STATE_NORMAL, &acolor);
-        gsd_osd_window_color_shade (&acolor, LIGHTNESS_MULT);
-        gsd_osd_window_color_reverse (&acolor);
-        acolor.alpha = GSD_OSD_WINDOW_FG_ALPHA / 2;
-        gdk_cairo_set_source_rgba (cr, &acolor);
-        cairo_set_line_width (cr, 1);
-        cairo_stroke (cr);
+        cairo_fill (cr);
 
         /* bar progress */
         if (percentage < 0.01)
                 return;
         gtk_style_context_get_background_color (context, GTK_STATE_NORMAL, &acolor);
         acolor.alpha = GSD_OSD_WINDOW_FG_ALPHA;
-        gsd_osd_window_draw_rounded_rectangle (cr, 1.0, _x0 + 0.5, _y0 + 0.5, height / 6 - 0.5, x1, height - 1);
+        gsd_osd_window_draw_rounded_rectangle (cr, 1.0, _x0, _y0, height / 6, x1, height);
         gdk_cairo_set_source_rgba (cr, &acolor);
         cairo_fill (cr);
 }
@@ -424,13 +416,13 @@ draw_action_volume (GsdMediaKeysWindow *window,
 
         gtk_window_get_size (GTK_WINDOW (window), &window_width, &window_height);
 
-        icon_box_width = round (window_width * 0.65);
-        icon_box_height = round (window_height * 0.65);
+        icon_box_width = round (window_width * ICON_SCALE);
+        icon_box_height = round (window_height * ICON_SCALE);
         volume_box_width = icon_box_width;
         volume_box_height = round (window_height * 0.05);
 
-        icon_box_x0 = (window_width - icon_box_width) / 2;
-        icon_box_y0 = (window_height - icon_box_height - volume_box_height) / 2 - volume_box_height;
+        icon_box_x0 = round ((window_width - icon_box_width) / 2);
+        icon_box_y0 = round ((window_height - icon_box_height - volume_box_height) / 2 - volume_box_height);
         volume_box_x0 = round (icon_box_x0);
         volume_box_y0 = round (icon_box_height + icon_box_y0) + volume_box_height;
 
@@ -561,13 +553,13 @@ draw_action_custom (GsdMediaKeysWindow *window,
 
         gtk_window_get_size (GTK_WINDOW (window), &window_width, &window_height);
 
-        icon_box_width = round (window_width * 0.65);
-        icon_box_height = round (window_height * 0.65);
+        icon_box_width = round (window_width * ICON_SCALE);
+        icon_box_height = round (window_height * ICON_SCALE);
         bright_box_width = round (icon_box_width);
         bright_box_height = round (window_height * 0.05);
 
-        icon_box_x0 = (window_width - icon_box_width) / 2;
-        icon_box_y0 = (window_height - icon_box_height - bright_box_height) / 2 - bright_box_height;
+        icon_box_x0 = round ((window_width - icon_box_width) / 2);
+        icon_box_y0 = round ((window_height - icon_box_height - bright_box_height) / 2 - bright_box_height);
         bright_box_x0 = round (icon_box_x0);
         bright_box_y0 = round (icon_box_height + icon_box_y0) + bright_box_height;
 
